@@ -1360,6 +1360,22 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_lostApp_list
 
+    def get_lostApp_onePage(self):
+        """
+            * 获取词下落榜App的数据-第一页：
+        """
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=out_time&sort_type=%s&type=out&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        res = session.get(url, headers=headers)
+        self.lostApp_onePage_data = res.json()
+        return self.lostApp_onePage_data
+
+    def get_lostApp_num(self):
+        """
+            * 获取词下落榜App的数量：
+        """
+        self.get_lostApp_onePage()
+        return self.lostApp_onePage_data['total_num']
+
     def get_newApp_list(self):
         """
             * 获取关键词下新覆盖产品的列表；
@@ -1376,6 +1392,22 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_newApp_list
 
+    def get_newApp_onePage(self):
+        """
+            * 获取词下新进App的数据-第一页：
+        """
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=new_time&sort_type=%s&type=new&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        res = session.get(url, headers=headers)
+        self.newApp_onePage_data = res.json()
+        return self.newApp_onePage_data
+
+    def get_newApp_num(self):
+        """
+            * 获取词下新进App的数量：
+        """
+        self.get_newApp_onePage()
+        return self.newApp_onePage_data['total_num']
+
     def get_rankDown_list(self):
         """
             * 获取关键词下排名下降较多的产品列表；
@@ -1392,6 +1424,22 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_rankDown_list
 
+    def get_rankDown_onePage(self):
+        """
+            * 获取词下排名下降较快App的数据-第一页：
+        """
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=down_rank&sort_type=%s&type=down&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        res = session.get(url, headers=headers)
+        self.rankDown_onePage_data = res.json()
+        return self.rankDown_onePage_data
+
+    def get_rankDown_num(self):
+        """
+            * 获取词下排名下降较快App的数量：
+        """
+        self.get_rankDown_onePage()
+        return self.rankDown_onePage_data['total_num']
+
     def get_rankGoUp_list(self):
         """
             * 获取关键词下排名上升较多的产品列表；
@@ -1408,6 +1456,22 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_rankUp_list
 
+    def get_rankGoUp_onePage(self):
+        """
+             * 获取词下排名上升较快App的数据-第一页：
+        """
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=up_rank&sort_type=%s&type=up&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
+        res = session.get(url, headers=headers)
+        self.rankGoUp_onePage_data = res.json()
+        return self.rankGoUp_onePage_data
+
+    def get_rankGoUp_num(self):
+        """
+             * 获取词下排名上升较快App的数量：
+        """
+        self.get_rankGoUp_onePage()
+        return self.rankGoUp_onePage_data['total_num']
+
     def get_t10App_list(self):
         """
             * 获取关键词下T10产品监控数据；
